Enum Transform
#[non_exhaustive]#[repr(u32)]pub enum Transform {
Normal = 0,
_90 = 1,
_180 = 2,
_270 = 3,
Flipped = 4,
Flipped90 = 5,
Flipped180 = 6,
Flipped270 = 7,
}Available on crate feature
wayland and Linux only.Expand description
transformation applied to buffer contents
This describes transformations that clients and compositors apply to buffer contents.
The flipped values correspond to an initial flip around a vertical axis followed by rotation.
The purpose is mainly to allow clients to render accordingly and tell the compositor, so that for fullscreen surfaces, the compositor will still be able to scan out directly from client surfaces.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal = 0
no transform
_90 = 1
90 degrees counter-clockwise
_180 = 2
180 degrees counter-clockwise
_270 = 3
270 degrees counter-clockwise
Flipped = 4
180 degree flip around a vertical axis
Flipped90 = 5
flip and rotate 90 degrees counter-clockwise
Flipped180 = 6
flip and rotate 180 degrees counter-clockwise
Flipped270 = 7
flip and rotate 270 degrees counter-clockwise